.. index:: core

.. _skpar.core:

core sub-package modules
===========================================================

Main Program (skpar.core.skpar)
-------------------------------------

.. automodule:: skpar.core.skpar
    :members:
    :undoc-members:
    :show-inheritance:


Input handler (skpar.core.input)
----------------------------------

.. automodule:: skpar.core.input
    :members:
    :undoc-members:


Tasks (skpar.core.tasks)
-------------------------

.. automodule:: skpar.core.tasks
    :members:
    :undoc-members:
    :show-inheritance:


Task Dictionary (skpar.core.taskdict)
-----------------------------------------

.. automodule:: skpar.core.taskdict
    :members:
    :undoc-members:


Objectives (skpar.core.objectives)
-----------------------------------

.. automodule:: skpar.core.objectives
    :members:
    :undoc-members:
    :show-inheritance:


Query (skpar.core.query)
-------------------------

.. automodule:: skpar.core.query
    :members:
    :undoc-members:
    :show-inheritance:


Evaluator (skpar.core.evaluate)
---------------------------------

.. automodule:: skpar.core.evaluate
    :members:
    :undoc-members:
    :show-inheritance:

Optimiser (skpar.core.optimise)
---------------------------------

.. automodule:: skpar.core.optimise
    :members:
    :undoc-members:
    :show-inheritance:

Parameters (skpar.core.parameters)
-----------------------------------

.. automodule:: skpar.core.parameters
    :members:
    :undoc-members:
    :show-inheritance:

.. _`pso`:

PSO (skpar.core.pso)
------------------------------

.. automodule:: skpar.core.pso
    :members:
    :undoc-members:
    :show-inheritance:

Utilities (skpar.core.utils)
------------------------------

.. automodule:: skpar.core.utils
    :members:
    :undoc-members:
    :show-inheritance:
